NotificationController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • NotificationController
Implemented types

Constructors

NotificationController({required ApiClient apiClient, required MySharedPref mySharedPref, required SenderNotificationLocalService senderNotificationLocalService, required FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin, required AndroidInitializationSettings initializationSettingsAndroid, required DarwinInitializationSettings initializationIos})

Properties

apiClient ↔ ApiClient
getter/setter pair
flutterLocalNotificationsPlugin → FlutterLocalNotificationsPlugin
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
id int
getter/setter pair
initializationIos → DarwinInitializationSettings
final
initializationSettingsAndroid → AndroidInitializationSettings
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
listeners int
no setterinherited
mySharedPref ↔ MySharedPref
getter/setter pair
notificationsEnabled bool
no setter
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderNotificationLocalService → SenderNotificationLocalService
final
timeReminderReadPlan String
no setter
userConnected ↔ UserModel
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
activateNotification({required String time, required int notificationId, required String codeLecture, String? codeSubscription, required String titre, required String description, String imageBg = '${Constant.assetsBiblePath}b1.jpg', required String pageUrl, ChannelModel? channel}) Future<void>
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
cancelAllNotification() Future<void>
cancelNotification({required int id}) Future<void>
checkDidNotificationLaunchApp() Future
configureLocalTimeZone() Future<void>
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
fetchActiveNotifications() Future<void>
fetchPendingNotificationRequest() Future<void>
getNavigatorPushNamed({required NotificationResponse? notificationResponse}) → dynamic
getTimeReminderReadPlan() → dynamic
handleNotification(dynamic data, bool push) → dynamic
init() → dynamic
initLocalNotification() Future
initNotification() Future
initOnDidReceiveBackgroundNotificationResponse() Future
iOSPermission() → void
modifyNotificationJson(dynamic message) → dynamic
This method will modify the message format of iOS Notification Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDidReceiveLocalNotificationIos(int id, String? title, String? body, String? payload) → void
onDidReceiveNotificationResponse(NotificationResponse details) → void
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onLaunch(dynamic message) Future<void>?
This method will be called on tap of the notification which came when app was closed
onMessage(dynamic message) Future<void>
This method will be called on tap of the notification which came when app was in foreground
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
performActionOnNotification(dynamic message) → void
We want to perform same action of the click of the notification. So this common method will be called on tap of any notification (onLaunch / onMessage / onResume)
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
repeatNotification() Future<void>
requestPermissions() Future<void>
stringToTimeOfDay(String tod) TimeOfDay
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited