NotificationLocalRepository class

Constructors

NotificationLocalRepository({required FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin})

Properties

flutterLocalNotificationsPlugin → FlutterLocalNotificationsPlugin
final
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateNotification({required String time, required PayLoadModel payLoad, ChannelModel? channel}) Future<void>
override
cancelAllNotification() Future<void>
override
cancelNotification({required int id}) Future<void>
override
getNotificationList() Future<Response?>
myBackgroundMessageHandler(dynamic message) Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
repeatNotification() Future<void>
override
scheduledDateTime({required String timeReminder}) → TZDateTime
showBigPictureNotificationHiddenLargeIcon({required MessageNotificationModel mNotif}) Future<void>
override
showBigTextNotification({required MessageNotificationModel mNotif}) Future<void>
override
showNotification({required dynamic message}) Future<void>
override
showNotificationDemo() Future<void>
override
showTextNotification({required MessageNotificationModel mNotif}) Future<void>
override
strToTimeOfDay(String tod) TimeOfDay
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

downloadAndSaveFile({required String url, required String fileName}) Future<String>