NotificationHelper class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
downloadAndSaveFile({required String url, required String fileName})
→ Future<String>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
showBigPictureNotificationHiddenLargeIcon({String? title, String? body, String? payload, required String imagePath, required FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin})
→ Future<void>
-
-
showBigTextNotification({String? title, required String body, String? payload, required FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin})
→ Future<void>
-
-
showNotification({required dynamic message, required FlutterLocalNotificationsPlugin fln, bool data = false})
→ Future<void>
-
-
showTextNotification({String? title, String? body, String? payload, required FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
initialize(FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin)
→ Future<void>
-
-
showBigPictureNotificationHiddenLargeIcon2(String title, String body, String orderID, String image, FlutterLocalNotificationsPlugin fln)
→ Future<void>
-
-
showBigTextNotification2(String title, String body, String orderID, FlutterLocalNotificationsPlugin fln)
→ Future<void>
-
-
showNotification2({required dynamic message, required FlutterLocalNotificationsPlugin fln, bool data = false})
→ Future<void>
-
-
showTextNotification2(String title, String body, String orderID, FlutterLocalNotificationsPlugin fln)
→ Future<void>
-